@@ -14,7 +14,7 @@ Including another URLconf
     2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
 """
 from django.urls import path
-from .views import SuccessView, HomeView, ListaView, CrearView, EditarView, EliminarView
+from .views import SuccessView, HomeView, ListaView, CrearView, EditarView, EliminarView, ComboView
 
 app_name = "modulo"
 urlpatterns = [
@@ -24,4 +24,5 @@ urlpatterns = [
     path('test/crear/', CrearView.as_view(), name='test-crear'),
     path('test/editar/<int:pk>/', EditarView.as_view(), name='test-editar'),
     path('test/eliminar/<int:pk>/', EliminarView.as_view(), name='test-eliminar'),
+    path('test/combo/', ComboView.as_view(), name='test-combo'),
 ]
